@@ -95,6 +95,9 @@
 #include <linux/interrupt.h>
 #include <linux/kthread.h>
 #include <linux/netdevice.h>
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0))
+#include <linux/hardirq.h>
+#endif
 #if (LINUX_VERSION_CODE >= KERNEL_VERSION(6, 6, 0))
 #include <net/netdev_rx_queue.h>
 #endif
@@ -214,6 +217,10 @@ typedef irqreturn_t(*FN_ISR) (int irq, void *dev_id, struct pt_regs *ptregs);
 #endif
 #endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 30) */
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 19, 0)
+#define in_irq() in_hardirq()
+#endif
+
 #ifndef __exit
 #define __exit
 #endif
